@@ -59,14 +59,6 @@ if($ARGV[0] eq "prepare") {
     utime time, timegm(0,0,12,1,0,100), "plainfile.txt";
     chmod 0666, "plainfile.txt";
 
-    open(FILE, ">emptyfile.txt") || errout "$!";
-    binmode FILE;
-    close(FILE);
-    # The mtime is specifically chosen to be an even number so that it can be
-    # represented exactly on a FAT file system.
-    utime time, timegm(0,0,12,1,0,100), "emptyfile.txt";
-    chmod 0666, "emptyfile.txt";
-
     open(FILE, ">rofile.txt") || errout "$!";
     binmode FILE;
     print FILE "Read-only test file to support curl test suite\n";
@@ -91,7 +83,6 @@ elsif($ARGV[0] eq "postprocess") {
     }
     chmod 0666, "$dirname/rofile.txt";
     unlink "$dirname/rofile.txt";
-    unlink "$dirname/emptyfile.txt";
     unlink "$dirname/plainfile.txt";
     rmdir "$dirname/asubdir";
 
